'use strict';

/* istanbul ignore file: ignore from coverage because it varies per eslint version */

var eslintNaming = void 0;

function _getNormalizer() {
  if (eslintNaming) {
    return eslintNaming;
  }

  var eslintVersionFunctions = [
  // eslint >= 7.8.0
  function () {
    var ESLintExports = require('eslint');

    var version = ESLintExports.ESLint.version;

    if (!version) {
      throw new Error('Unable to find eslint version');
    }

    var ESLintRC = require('@eslint/eslintrc');

    var naming = ESLintRC.Legacy.naming;

    return {
      normalizePackageName: naming.normalizePackageName,
      getShorthandName: naming.getShorthandName
    };
  },
  // eslint >= 6.1.0
  function () {
    var normalizer = require('eslint/lib/shared/naming');

    return {
      normalizePackageName: normalizer.normalizePackageName,
      getShorthandName: normalizer.getShorthandName
    };
  }];

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = eslintVersionFunctions[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var tryEslintVersion = _step.value;

      try {
        var normalizer = tryEslintVersion();

        if (typeof normalizer.normalizePackageName === 'function' && typeof normalizer.getShorthandName === 'function') {
          eslintNaming = {
            normalizePackageName: normalizer.normalizePackageName,
            getShorthandName: normalizer.getShorthandName
          };

          return eslintNaming;
        }
      } catch (err) {}
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  throw new Error('eslint naming functions not found');
}

function normalizePluginName(name) {
  var normalizer = _getNormalizer();

  var module = normalizer.normalizePackageName(name, 'eslint-plugin');
  var prefix = normalizer.getShorthandName(name, 'eslint-plugin');

  return { module, prefix };
}

module.exports = normalizePluginName;